MINOR: protocols: always pass a "port" argument to the listener creation

It's a shame that cfgparse() has to make special cases of each protocol
just to cast the port to the target address family. Let's pass the port
in argument to the function. The unix listener simply ignores it.
diff --git a/src/proto_uxst.c b/src/proto_uxst.c
index ac14d3b..767cd16 100644
--- a/src/proto_uxst.c
+++ b/src/proto_uxst.c
@@ -365,11 +365,11 @@
 	return ERR_NONE;
 }
 
 /* Add a listener to the list of unix stream listeners. The listener's state
  * is automatically updated from LI_INIT to LI_ASSIGNED. The number of
  * listeners is updated. This is the function to use to add a new listener.
  */
-void uxst_add_listener(struct listener *listener)
+void uxst_add_listener(struct listener *listener, int port)
 {
 	if (listener->state != LI_INIT)
 		return;
@@ -365,11 +365,11 @@
 }
 
-/* Add a listener to the list of unix stream listeners. The listener's state
- * is automatically updated from LI_INIT to LI_ASSIGNED. The number of
- * listeners is updated. This is the function to use to add a new listener.
+/* Add <listener> to the list of unix stream listeners (port is ignored). The
+ * listener's state is automatically updated from LI_INIT to LI_ASSIGNED.
+ * The number of listeners for the protocol is updated.
  */